"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.carboneFileDownloadRequest = exports.carboneFileUploadRequest = exports.carboneApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function carboneApiRequest(method, endpoint, body = {}, qs = {}) {
    const credentials = await this.getCredentials('carboneApi');
    const options = {
        headers: {
            Authorization: `Bearer ${credentials.apiToken}`,
            'carbone-version': 4,
        },
        method,
        body,
        qs,
        uri: `${credentials.domain}/${endpoint}`,
        json: true,
        gzip: true,
        rejectUnauthorized: true,
    };
    if (Object.keys(qs).length === 0) {
        delete options.qs;
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.carboneApiRequest = carboneApiRequest;
async function carboneFileUploadRequest(method, endpoint, body = {}, qs = {}) {
    const credentials = await this.getCredentials('carboneApi');
    const options = {
        headers: {
            'authorization': `bearer ${credentials.apiToken}`,
            'Content-Type': 'multipart/form-data',
            'carbone-version': 4,
        },
        method,
        body,
        qs,
        uri: `${credentials.domain}/${endpoint}`,
        json: true,
        gzip: true,
        rejectUnauthorized: true,
    };
    if (Object.keys(qs).length === 0) {
        delete options.qs;
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.carboneFileUploadRequest = carboneFileUploadRequest;
async function carboneFileDownloadRequest(method, endpoint, body = {}, qs = {}) {
    const credentials = await this.getCredentials('carboneApi');
    const options = {
        headers: {
            'authorization': `bearer ${credentials.apiToken}`,
            'accept': `*/*`,
            'carbone-version': 4,
        },
        method,
        body,
        qs,
        uri: `${credentials.domain}/${endpoint}`,
        json: false,
        gzip: true,
        rejectUnauthorized: true,
        encoding: null,
        resolveWithFullResponse: true,
    };
    if (Object.keys(qs).length === 0) {
        delete options.qs;
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.carboneFileDownloadRequest = carboneFileDownloadRequest;
//# sourceMappingURL=GenericFunctions.js.map